`kind` deploys MLOps `stack` on top of [kind cluster](https://kind.sigs.k8s.io/) on your machine. Please ensure that docker is installed and running on your machine, along with the latest version of kind.


#### Complete

===+ "Simple Deployment Configuration"
    ```yaml
    --8<-- "docs/examples/local/kind.yaml"
    ```
=== "Advanced Deployment Configuration"
    ```yaml
    --8<-- "docs/examples/local/kind-advanced.yaml"
    ```
